#pragma interface

class FWPORT: public ARRAY_OBJ {
public:
	SSTRING protocol;		// "tcp", "udp"
	int port;
	SSTRING program;
	SSTRING user;
	int uid;
	int pid;
	char accept;
	
	/*~PROTOBEG~ FWPORT */
public:
	FWPORT();
	/*~PROTOEND~ FWPORT */
};

class FWPORTLIST: public ARRAY {
private:
	void udp_do_one( int lnr, const char *line );
	void tcp_do_one( int lnr, const char *line );
	int getlist_tcp( void );
	int getlist_udp( void );
	/*~PROTOBEG~ FWPORTLIST */
public:
	FWPORTLIST();
	FWPORT *getitem( int item ) const;
	void read( void );
	void sort( void );
	void update_from_db( void );
	/*~PROTOEND~ FWPORTLIST */
};

static const char K_FIREWALL[] = "firewall";
